navigator_resizable library

Classes

A widget that observes the lifecycle of Routes.
The state of NavigatorEventObserver.
A thin wrapper around Navigator that visually resizes the child navigator to match the size of the content displayed in the current route.
ResizableMaterialPage<T>
A specialized MaterialPage compatible with NavigatorResizable.
ResizableMaterialPageRoute<T>
A specialized MaterialPageRoute compatible with NavigatorResizable.
ResizableNavigatorRouteContentBoundary
Observes the layout of the child widget and notifies the ancestor NavigatorResizable when the child's size changes.
ResizablePageRouteBuilder<T>
A utility class for defining one-off PageRoutes in terms of callbacks.
ResizablePageRoutePageBuilder<T>
A utility class for defining one-off Page that creates PageRoute in terms of callbacks.

Mixins

An interface for observing the lifecycle of Routes.
ObservableRouteMixin<T>
A mixin for Routes that notifies the ancestor NavigatorEventObserver of lifecycle events.